.. cspell:words toctree maxdepth

:hide-toc:

.. include:: ../README.rst

.. toctree::
   :maxdepth: 1
   :caption: User Guide
   :hidden:

   getting_started

.. toctree::
   :maxdepth: 1
   :caption: Rayne Reference
   :hidden:

   benchmark

.. toctree::
   :maxdepth: 1
   :caption: Development
   :hidden:

   release_notes
   Repository <https://github.com/brobeson/Rayne>
   Report an Issue <https://github.com/brobeson/Rayne/issues>
   PyPI <https://pypi.org/project/rayne/>
